# Base Python Template

[![Downloads](https://static.pepy.tech/personalized-badge/akms-logs-package?period=total&units=none&left_color=grey&right_color=green&left_text=Downloads)](https://pepy.tech/project/akms-logs-package)

A template of README best practices to make your README simple to understand and easy to use.

## Table of Contents

- [Installation](#installation)
- [Usage](#usage)
- [Support](#support)
- [Contributing](#contributing)

## Installation

Install the package using pip:

```sh
pip install base
```

## Usage

```python
from base_python_package_template import greetings

greeting = greetings()
print(greeting)
```

## Support

Please [open an issue](https://github.com/apinanyogaratnam/akms-logs-package/issues/new) for support.

## Contributing

Please contribute using [Github Flow](https://guides.github.com/introduction/flow/). Create a branch, add commits, and [open a pull request](https://github.com/apinanyogaratnam/akms-logs-package/compare/).
